@@ -1,14 +1,14 @@
-from PySide6 import QtCore, QtWidgets, QtGui
-
-from .utils.helper import AttributeNameValidator, IntDelegate, FloatDelegate, DateTimeDelegate, BoolDelegate, \
-    StrDelegate
-from .utils.editable_label import EditableLabel
-
-from typing import Union, Type, Optional, Dict, cast
-
-from tscat.filtering import Comparison, Field, Attribute, Any, All, Not, In, InCatalogue, Has, Predicate, Match
-import tscat.filtering
 import datetime as dt
+import typing
+from typing import Dict, Optional, Type, Union, cast
+
+from PySide6 import QtCore, QtGui, QtWidgets
+
+import tscat.filtering
+from tscat.filtering import All, Any, Attribute, Comparison, Field, Has, In, InCatalogue, Match, Not, Predicate
+from .utils.editable_label import EditableLabel
+from .utils.helper import AttributeNameValidator, BoolDelegate, DateTimeDelegate, FloatDelegate, IntDelegate, \
+    StrDelegate
 
 
 class _PredicateWidget(QtWidgets.QWidget):
@@ -30,7 +30,7 @@ class _Root(_PredicateWidget):
     def __init__(self, predicate: Predicate):
         super().__init__(None)
 
-        self._first = predicate_to_widget_factory(predicate, None)
+        self._first = predicate_to_widget_factory(predicate, self)
         if self._first:
             c = QtWidgets.QHBoxLayout()
             c.setContentsMargins(0, 0, 0, 0)
@@ -179,6 +179,7 @@ class _Comparison(_PredicateWidget):
 
         self._current_value_widget = widget
         self._layout.addWidget(widget)
+        widget.show()
         self.changed.emit()
 
     def predicate(self) -> Optional[Union[Comparison, Match, Not]]:
@@ -298,7 +299,7 @@ class _InCatalogue(_PredicateWidget):
 
     OP_LABELS = ['is in catalogue', 'is not in catalogue']
 
-    def __init__(self, predicate: Union[InCatalogue, None], negate: bool, parent: _PredicateWidget):
+    def __init__(self, predicate: Optional[InCatalogue], negate: bool, parent: _PredicateWidget):
         super().__init__(parent)
 
         c = QtWidgets.QHBoxLayout()
@@ -309,11 +310,29 @@ class _InCatalogue(_PredicateWidget):
         c.addWidget(self._op_label)
 
         self.catalogues = QtWidgets.QComboBox()
-        for cat in tscat.get_catalogues():
-            self.catalogues.addItem(cat.name, cat)
 
-        for cat in tscat.get_catalogues(removed_items=True):
-            self.catalogues.addItem(cat.name + " (in trash)", cat)
+        from .tscat_driver.model import tscat_model
+        from .tscat_driver.nodes import CatalogNode
+
+        for cat in tscat_model.tscat_root().catalogue_nodes(in_trash=False):
+            if isinstance(cat, CatalogNode):
+                self.catalogues.addItem(cat.name, cat.node)
+
+        for cat in tscat_model.tscat_root().catalogue_nodes(in_trash=True):
+            if isinstance(cat, CatalogNode):
+                self.catalogues.addItem(cat.name + " (in trash)", cat.node)
+
+        if predicate is not None:
+            for index in range(self.catalogues.count()):
+                catalogue = cast(tscat._Catalogue, self.catalogues.itemData(index))
+                if catalogue and predicate.catalogue and predicate.catalogue.uuid == catalogue.uuid:
+                    break
+            else:
+                index = -1
+
+            if index != -1:
+                self.catalogues.setCurrentIndex(index)
+
         self.catalogues.currentIndexChanged.connect(lambda: self.changed.emit())  # type: ignore
 
         c.addWidget(self.catalogues)
@@ -353,7 +372,8 @@ operators = [
 
 class _Condition(_PredicateWidget):
     def __init__(self, predicate: Union[Comparison, Match, In, Has, InCatalogue, None],
-                 parent: Optional[_PredicateWidget]):
+                 negate: bool,
+                 parent: _PredicateWidget):
         super().__init__(parent)
 
         self._hlayout = QtWidgets.QHBoxLayout()
@@ -431,13 +451,16 @@ class _Condition(_PredicateWidget):
 
 
 class _LogicalCombination(_PredicateWidget):
-    def __init__(self, predicate: Union[All, Any, None], parent: Optional[_PredicateWidget]):
+    def __init__(self,
+                 predicate: Union[All, Any, None],
+                 negate: bool,
+                 parent: _PredicateWidget):
         super().__init__(parent)
 
         if predicate is None:
             predicate = Any()
 
-        self._children: list[_PredicateWidget] = []
+        self._children: typing.List[_PredicateWidget] = []
 
         self._layout = QtWidgets.QVBoxLayout()
         self._layout.setContentsMargins(20, 0, 0, 0)
@@ -478,8 +501,14 @@ class _LogicalCombination(_PredicateWidget):
 
         self.setLayout(self._layout)
 
-    def new(self, cls: Type[_PredicateWidget]):
-        t = cls(predicate=None, parent=self)
+    def new(self, cls: Union[
+            Type['_LogicalCombination'],
+            Type[_Condition],
+            Type[_Comparison],
+            Type[_AttributeIsPresent],
+            Type[_StringInStringList],
+            Type[_InCatalogue]]):
+        t = cls(predicate=None, negate=False, parent=self)
         self._layout.insertWidget(self._layout.count() - 1, t)
         self.add_child_predicate(t)
         self.changed.emit()
@@ -507,13 +536,13 @@ class _LogicalCombination(_PredicateWidget):
         self.changed.emit()
 
 
-def predicate_to_widget_factory(predicate: Predicate, parent: Optional[_PredicateWidget]) -> \
+def predicate_to_widget_factory(predicate: Predicate, parent: _PredicateWidget) -> \
     Union[_LogicalCombination, _Condition]:
     if isinstance(predicate, Any) or isinstance(predicate, All):
-        return _LogicalCombination(predicate, parent)
+        return _LogicalCombination(predicate, False, parent)
     elif isinstance(predicate, Comparison) or isinstance(predicate, Match) or \
         isinstance(predicate, In) or isinstance(predicate, Has) or isinstance(predicate, InCatalogue):
-        return _Condition(predicate, parent)
+        return _Condition(predicate, False, parent)
 
     raise ValueError('Unknown predicate type for factory')
 
@@ -552,11 +581,11 @@ class _DeletePredicateWidget(QtWidgets.QToolButton):
 
         self.setText('✖')
 
-        self.clicked.connect(lambda: cast(widget.parent(), QtWidgets.QWidget).delete_child(widget))  # type: ignore
+        self.clicked.connect(lambda: widget.parent().delete_child(widget))  # type: ignore
 
 
 class SimplePredicateEditDialog(QtWidgets.QDialog):
-    def __init__(self, predicate: Optional[tscat.Predicate], parent=None):
+    def __init__(self, predicate: Optional[Predicate], parent=None):
         super().__init__(parent)
 
         layout = QtWidgets.QVBoxLayout()
