@@ -12,13 +12,14 @@ class EditableLabel(QtWidgets.QFrame):
 
         def __init__(self, text: str, parent=None):
             super().__init__(text, parent)
+            self.setObjectName('EditableLabel--Label')
 
         def mousePressEvent(self, event: QtGui.QMouseEvent) -> None:
             if event.button() == QtCore.Qt.MouseButton.LeftButton:
                 self.clicked.emit()
             super().mousePressEvent(event)
 
-        def enterEvent(self, event: QtCore.QEvent) -> None:  # type: ignore
+        def enterEvent(self, event: QtGui.QEnterEvent) -> None:
             self.setCursor(QtCore.Qt.IBeamCursor)  # type: ignore
             super().enterEvent(event)
 
@@ -33,7 +34,7 @@ class EditableLabel(QtWidgets.QFrame):
 
         def __init__(self, text: str, validator: QtGui.QValidator, parent=None):
             super().__init__(text, parent)
-
+            self.setObjectName('EditableLabel--LineEdit')
             self.setValidator(validator)
 
             self.textChanged.connect(self.text_changed)  # type: ignore
@@ -66,9 +67,8 @@ class EditableLabel(QtWidgets.QFrame):
 
             super().keyPressEvent(event)
 
-    def __init__(self, text: str, validator: QtGui.QValidator = None, parent=None):
+    def __init__(self, text: str, validator: typing.Optional[QtGui.QValidator] = None, parent=None):
         super().__init__(parent)
-
         self.setSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)  # type: ignore
 
         self.text = text
