@@ -7,7 +7,7 @@ import re
 import typing
 
 # UTF-8 letters in the beginning, then also numbers and underscore
-_tag_validation_regex = re.compile(r'[a-z]\w*')
+_tag_validation_regex = re.compile(r'^[a-z][^,]*$')
 
 
 class _Keyword(EditableLabel):
@@ -20,13 +20,6 @@ class _Keyword(EditableLabel):
             super().__init__('✕', parent)
             self.setMargin(1)
             self.setObjectName('DeleteLabel')
-            self.setStyleSheet(
-                f"""#DeleteLabel {{
-                    border-radius: 5px;
-                    background: {self.palette().dark().color().name()};
-                    min-width: 10px;
-                    min-height: 10px;
-                }}""")
 
         def enterEvent(self, event: QtCore.QEvent) -> None:
             self.setText('✖')
@@ -67,10 +60,6 @@ class _Keyword(EditableLabel):
         self._layout.setContentsMargins(5, 5, 5, 5)
 
         self.setObjectName('OneKeyword')
-        self.setStyleSheet(f"""#OneKeyword {{
-                border-radius: 15px;
-                background: {self.palette().mid().color().name()};
-            }}""")
 
     def edit(self):
         super().edit()
@@ -84,13 +73,14 @@ class _Keyword(EditableLabel):
 class EditableKeywordListWidget(QtWidgets.QWidget):
     editingFinished = QtCore.Signal()
 
-    def __init__(self, strings: list[str], completion_strings: list[str] = [], parent=None):
+    def __init__(self, strings: typing.List[str], completion_strings: typing.List[str] = [], parent=None):
         super().__init__(parent)
 
         self._layout = FlowLayout()
 
-        self.new_tag = QtWidgets.QToolButton()
+        self.new_tag = QtWidgets.QToolButton(self)
         self.new_tag.setText('➕')
+        self.new_tag.setObjectName('NewTagButton')
         self.new_tag.clicked.connect(lambda _: self._add_tag('', edit=True))  # type: ignore
         self._layout.addWidget(self.new_tag)
 
@@ -138,5 +128,5 @@ class EditableKeywordListWidget(QtWidgets.QWidget):
 
         self._update_tag_texts()
 
-    def value(self) -> list[str]:
+    def value(self) -> typing.List[str]:
         return [tag.text for tag in self.tags if tag.text]
